﻿Imports System.Runtime.InteropServices

Module HVProbe

    ' File      : HVProbe.vb
    ' Function  : VB.NET include file for applications using CPS high voltage USB probes
    ' Author    : Jim Lamberson
    ' Copyright : (C) CPS, 2015

    ' Constants ----------------------------------------------

    Public Const MAX_NUM_PROBES As Integer = 16             ' Maximum number of probes supported by API

    ' API error codes
    Public Const HVP_ERR_OK As Integer = 0                  ' No errors
    Public Const HVP_ERR_DEVICE_MALLOC As Integer = (-1)    ' Insufficient memory
    Public Const HVP_ERR_DEVICE_OPEN As Integer = (-2)      ' Error reading device info
    Public Const HVP_ERR_READ_OPEN As Integer = (-3)        ' Can't open device for reading
    Public Const HVP_ERR_WRITE_OPEN As Integer = (-4)       ' Can't open device for writing
    Public Const HVP_ERR_READ As Integer = (-5)             ' Error reading device
    Public Const HVP_ERR_WRITE As Integer = (-6)            ' Error writing device
    Public Const HVP_ERR_PROBE_ID As Integer = (-7)         ' Invalid probe number
    Public Const HVP_ERR_CHECKSUM As Integer = (-8)         ' Invalid calibration and serial number
    Public Const HVP_ERR_PROBE_CLOSED As Integer = (-9)     ' Probe is not open
    Public Const HVP_ERR_DEVICE_PARAM As Integer = (-10)    ' Unexpected device parameter

    ' Bit masks for status value returned by HVP_GetStatus()
    Public Const HVP_STATUS_ALARM As Integer = 1            ' HV proximity detected while probe ground lead is floating

    ' Types -------------------------------------------------

    <StructLayout(LayoutKind.Sequential, CharSet:=CharSet.Ansi)> _
    Public Structure PROBE_INFO                             ' PROBE ATTRIBUTES -------
        Public model As Integer                             '   Model number
        Public version As UInt32                            '   Firmware version
        Public serialnum As UInt32                          '   Serial number
        Public vscale_dc As Double                          '   Scale of DC meters
        Public vscale_ac As Double                          '   Scale of AC meter
        <MarshalAs(UnmanagedType.ByValTStr, SizeConst:=128)> _
        Public firmware_info As String                      '   Firmware info string
    End Structure

    Public Structure METER_DATA                             ' METER DATA ----------
        Public meter_dc As Double                           '   DC meter
        Public meter_ac As Double                           '   AC meter
        Public meter_min As Double                          '   DC minimum peak detector
        Public meter_max As Double                          '   DC maximum peak detector
        Public meter_t As Double                            '   Probe internal temperature
    End Structure

    ' API functions -----------------------------------------

    <DllImport("HVProbe.dll")> _
        Public Function HVP_OpenSystem() As Int32
    End Function

    <DllImport("HVProbe.dll")> _
        Public Function HVP_CloseSystem() As Int32
    End Function

    <DllImport("HVProbe.dll")> _
        Public Function HVP_OpenProbe(ByVal ProbeID As Integer) As Int32
    End Function

    <DllImport("HVProbe.dll")> _
        Public Function HVP_CloseProbe(ByVal ProbeID As Integer) As Int32
    End Function

    <DllImport("HVProbe.dll")> _
        Public Function HVP_GetAttributes(ByVal ProbeID As Integer, ByRef info As PROBE_INFO) As Int32
    End Function

    <DllImport("HVProbe.dll")> _
        Public Function HVP_GetStatus(ByVal ProbeID As Integer, ByRef Status As Integer) As Int32
    End Function

    <DllImport("HVProbe.dll")> _
        Public Function HVP_GetMeters(ByVal ProbeID As Integer, ByRef Data As METER_DATA) As Int32
    End Function

End Module
