﻿Public Class vb_demo

    '-------------------------------------------------------------
    ' Simple VB.NET demo program for CPS USB high voltage probes
    '-------------------------------------------------------------

    Private Sub DemoFormLoad(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim info As New PROBE_INFO
        Dim errcode As Integer = HVP_OpenSystem()   ' open system and probe
        If (errcode < 0) Then FatalError(errcode)
        If (errcode = 0) Then lblProbeInfo.Text = "No probes detected" : Exit Sub
        errcode = HVP_OpenProbe(0)
        If (errcode < 0) Then
            If (errcode <> HVP_ERR_CHECKSUM) Then FatalError(errcode)
            MsgBox("HV probe is not calibrated", MsgBoxStyle.OkOnly, "Warning")
        End If
        errcode = HVP_GetAttributes(0, info)        ' read and display probe attributes
        If (errcode < 0) Then FatalError(errcode)
        lblProbeInfo.Text = "Model " & info.model.ToString & vbCrLf & "Serial number " & info.serialnum.ToString & vbCrLf & "Firmware " & info.firmware_info.ToString
        grpDataLogging.Enabled = True
        tmrUpdateDisplay.Enabled = True   ' 
        cmbLogTimeUnits.SelectedIndex = 0
    End Sub

    Private Sub DemoFormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        If (tmrLogSample.Enabled) Then CloseLog("Logging halted due to application shutdown")
        tmrUpdateDisplay.Enabled = False
        HVP_CloseSystem()
    End Sub

    Private Sub UpdateDisplay_Tick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles tmrUpdateDisplay.Tick
        Dim MeterData As New METER_DATA
        Dim errcode As Integer = HVP_GetMeters(0, MeterData)
        If (errcode < 0) Then FatalError(errcode)
        lblProbeData.Text = Format(MeterData.meter_dc, "####0.0")
    End Sub

    Private Sub FatalError(ByVal errcode As Integer)
        Dim emsg As String
        Select Case errcode
            Case HVP_ERR_DEVICE_MALLOC : emsg = "Insufficient memory"
            Case HVP_ERR_DEVICE_OPEN : emsg = "Can't read device info"
            Case HVP_ERR_READ_OPEN : emsg = "Can't open device for reading"
            Case HVP_ERR_WRITE_OPEN : emsg = "Can't open device for writing"
            Case HVP_ERR_READ : emsg = "Can't read device"
            Case HVP_ERR_WRITE : emsg = "Can't write device"
            Case HVP_ERR_PROBE_ID : emsg = "Invalid probe number"
            Case HVP_ERR_CHECKSUM : emsg = "Invalid calibration and serial number"
            Case HVP_ERR_PROBE_CLOSED : emsg = "Probe is not open"
            Case HVP_ERR_DEVICE_PARAM : emsg = "Unexpected device parameter"
            Case Else : emsg = errcode.ToString
        End Select
        tmrUpdateDisplay.Enabled = False
        If (tmrLogSample.Enabled) Then CloseLog("Logging halted due to error (" & emsg & ")")
        MsgBox("Error: " & emsg, MsgBoxStyle.OkOnly, "HV Probe Error")
        lblProbeInfo.Text = "Error: " & errcode.ToString
        Environment.Exit(0)
    End Sub

    ' DATA LOGGING FUNCTIONS ------------------------------

    Private LogStream As System.IO.StreamWriter
    Private LogStartTime As DateTime

    Private Sub CloseLog(ByVal Reason As String)
        If (tmrLogSample.Enabled) Then
            LogStream.Write(Reason & vbCrLf)
            LogStream.Flush()
            LogStream.Close()
            tmrLogSample.Enabled = False
        End If
        btnStopLog.Enabled = False
        lblLogFilename.Text = "Click to select log file and start logging"
        pnlLogConfig.Enabled = True
    End Sub

    Private Sub OpenLog(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles lblLogFilename.Click
        Dim LogFileDialog As New SaveFileDialog()
        LogFileDialog.Title = "Select Data Logger Output File"
        LogFileDialog.Filter = "txt files (*.txt)|*.txt|All files (*.*)|*.*"
        LogFileDialog.FilterIndex = 2
        LogFileDialog.OverwritePrompt = True
        LogFileDialog.RestoreDirectory = True
        If (LogFileDialog.ShowDialog() = DialogResult.OK) Then
            LogStream = New System.IO.StreamWriter(LogFileDialog.FileName, False, System.Text.Encoding.ASCII) ' open log file
            LogStream.Write("CPS High Voltage Probe Log File " & DateTime.Now & vbCrLf) ' output header to log file
            LogStream.Write("Format: ElapsedSeconds, Volts" & vbCrLf)
            LogStartTime = DateTime.Now
            ' Config controls for active logging
            pnlLogConfig.Enabled = False
            btnStopLog.Enabled = True
            lblLogFilename.Text = LogFileDialog.FileName
            tmrLogSample.Interval = updnLogInterval.Value * IIf(cmbLogTimeUnits.SelectedIndex = 0, 1000, 60000)
            tmrLogSample.Enabled = True
        End If
    End Sub

    Private Sub StopLogging(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnStopLog.Click
        CloseLog("Logging halted by operator")
    End Sub

    Private Sub LogSample(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles tmrLogSample.Tick
        Dim MeterData As New METER_DATA
        Dim errcode As Integer = HVP_GetMeters(0, MeterData)
        If (errcode < 0) Then FatalError(errcode)
        LogStream.Write(Format((DateTime.Now - LogStartTime).TotalSeconds, "##########0.0") & ", " & Format(MeterData.meter_dc, "####0.00") & vbCrLf)
    End Sub

End Class
